%-----------------
% define constants
%-----------------
  critical_stress = 0.016   ; % critical shear stress for sediment erosion [N/m2]
  cya0            = 4.5E-9  ; % seed concentration for diazotroph cyanobacteria [mol/kg]
  din_min_lpp     = 1.125E-6; % DIN half saturation constant for large-cell phytoplankton growth [mol/kg]
  din_min_spp     = 4.5E-7  ; % DIN half saturation constant for small-cell phytoplankton growth [mol/kg]
  dip_min_cya     = 1.125E-7; % DIP half saturation constant for diazotroph cyanobacteria growth [mol/kg]
  epsilon         = 4.5E-17 ; % no division by 0
  food_min_zoo    = 4.108E-6; % Ivlev phytoplankton concentration for zooplankton grazing [mol/kg]
  gamma0          = 0.18    ; % light attenuation parameter (opacity of clear water) [1/m]
  gamma1          = 30.0    ; % light attenuation parameter (opacity of POM containing chlorophyll) [m**2/mol]
  h2s_min_po4_liber = 1.0E-6  ; % minimum h2s concentration for liberation of iron phosphate from the sediment [mol/kg]
  ips_threshold   = 0.1     ; % threshold for increased PO4 burial [mol/m**2]
  ips_cl          = 0.02025 ; % iron phosphate in sediment closure parameter [mol/m2]
  k_h2s_no3       = 800000.0; % reaction constant h2s oxidation with no3 [kg/mol/d]
  k_h2s_o2        = 800000.0; % reaction constant h2s oxidation with o2 [kg/mol/d]
  k_sul_no3       = 20000.0 ; % reaction constant sulfur oxidation with no3 [kg/mol/d]
  k_sul_o2        = 20000.0 ; % reaction constant sulfur oxidation with o2 [kg/mol/d]
  light_opt_cya   = 50.0    ; % optimal light for diazotroph cyanobacteria growth [W/m]
  light_opt_lpp   = 35.0    ; % optimal light for large-cell phytoplankton growth [W/m]
  light_opt_spp   = 50.0    ; % optimal light for small-cell phytoplankton growth [W/m]
  lpp0            = 4.5E-9  ; % seed concentration for large-cell phytoplankton [mol/kg]
  no3_min_sed_denit = 1.423E-7; % nitrate half-saturation concentration for denitrification in the water column [mol/kg]
  no3_min_det_denit = 1.0E-9  ; % minimum no3 concentration for recycling of detritus using nitrate (denitrification)
  o2_min_det_resp = 1.0E-6  ; % oxygen half-saturation constant for detritus recycling [mol/kg]
  o2_min_nit      = 3.75E-6 ; % oxygen half-saturation constant for nitrification [mol/kg]
  o2_min_po4_retent = 3.75E-5 ; % oxygen half-saturation concentration for retension of phosphate during sediment denitrification [mol/kg]
  o2_min_sed_resp = 6.4952E-5; % oxygen half-saturation constant for recycling of sediment detritus using oxygen [mol/kg]
  patm_co2        = 35.8    ; % atmospheric partial pressure of CO2 [Pa]
  q10_det_rec     = 0.15    ; % temperature dependence of recycling according to van t Hoffs rule [1/K], equivalent to Q10=4.5
  q10_h2s         = 0.0693  ; % temperature dependence of oxidation of h2s and sul according to van t Hoffs rule [1/K], equivalent to Q10=2.0
  q10_nit         = 0.11    ; % temperature dependence of nitrification according to van t Hoffs rule [1/K], equivalent to Q10=3.0
  q10_sed_rec     = 0.175   ; % temperature dependence of detritus recycling in the sediment according to van t Hoffs rule [1/K], equivalent to Q10=5.8
  r_biores        = 0.03    ; % bio-resuspension rate [1/d]
  r_cya_assim     = 0.75    ; % maximum rate for nutrient uptake of diazotroph cyanobacteria [1/d]
  r_det_rec       = 0.003   ; % recycling rate (detritus to ammonium) at 0C [1/d]
  r_ips_burial    = 0.007   ; % final burial rate for PO4 [1/d]
  r_ips_ero       = 6.0     ; % erosion rate for iron PO4 [1/d]
  r_ips_liber     = 0.1     ; % PO4 liberation rate under anoxic conditions [1/d]
  r_lpp_assim     = 1.3     ; % maximum rate for nutrient uptake of large-cell phytoplankton [1/d]
  r_nh4_nitrif    = 0.1     ; % nitrification rate at 0C [1/d]
  r_pp_mort       = 0.02    ; % mortality rate of phytoplankton [1/d]
  r_pp_resp       = 0.01    ; % respiration rate of phytoplankton to ammonium [1/d]
  r_sed_ero       = 6.0     ; % maximum sediment detritus erosion rate [1/d]
  r_sed_rec       = 0.002   ; % maximum recycling rate of sediment to ammonium [1/d]
  r_spp_assim     = 0.4     ; % maximum rate for nutrient uptake of small-cell phytoplankton [1/d]
  r_zoo_graz      = 0.5     ; % maximum zooplankton grazing rate [1/d]
  r_zoo_mort      = 0.03    ; % mortality rate of zooplankton [1/d]
  r_zoo_resp      = 0.01    ; % respiration rate of zooplankton [1/d]
  rfr_c           = 6.625   ; % redfield ratio C/N
  rfr_h           = 16.4375 ; % redfield ratio H/N
  rfr_o           = 6.875   ; % redfield ratio O/N
  rfr_p           = 0.0625  ; % redfield ratio P/N
  sali_max_cya    = 10.0    ; % upper salinity limit - diazotroph cyanobacteria [psu]
  sali_min_cya    = 1.0     ; % lower salinity limit - diazotroph cyanobacteria [psu]
  sed_max         = 4.5     ; % maximum sediment detritus concentration that feels erosion [mol/m**2]
  spp0            = 4.5E-9  ; % seed concentration for small-cell phytoplankton [mol/kg]
  temp_min_cya    = 13.5    ; % lower temperature limit - diazotroph cyanobacteria [C]
  temp_min_spp    = 10.0    ; % lower temperature limit - small-cell phytoplankton [C]
  temp_opt_zoo    = 20.0    ; % optimal temperature for zooplankton grazing [C]
  w_co2_stf       = 0.5     ; % piston velocity for co2 surface flux [m/d]
  w_cya           = 0.1     ; % vertical speed of diazotroph cyanobacteria [m/d]
  w_det           = -4.5    ; % vertical speed of detritus [m/d]
  w_det_sedi      = -2.25   ; % sedimentation speed (negative for downward) [m/d]
  w_ipw           = -1.0    ; % vertical speed of suspended iron PO4 [m/d]
  w_ipw_sedi      = -0.5    ; % sedimentation speed for iron PO4 [m/d]
  w_lpp           = -0.5    ; % vertical speed of large-cell phytoplankton [m/d]
  w_n2_stf        = 5.0     ; % piston velocity for n2 surface flux [m/d]
  w_o2_stf        = 5.0     ; % piston velocity for oxygen surface flux [m/d]
  zoo0            = 4.5E-9  ; % seed concentration for zooplankton [mol/kg]
  zoo_cl          = 9.0E-8  ; % zooplankton closure parameter [mol/kg]
